//
//  Newton Connection Library - Newton/Linux Connectivity
//  Copyright (C) 1995  Anthony Edward Hall
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Library General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Library General Public License for more details.
//
//  You should have received a copy of the GNU Library General Public
//  License along with this library; if not, write to the Free
//  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

//  $Id: Newton.H,v 1.38 1996/01/09 00:59:46 aehall Exp $

#ifndef _NEWTON_H_

#include <stdio.h>
#include <String.h>
#include <bool.h>
#include <SFile.h>

#define NewtonVERSION     "1.99"
#define NewtonTITLE       "Newton/Linux Connection Library v" NewtonVERSION
#define NewtonCOPYRIGHT   "Copyright (C) 1995  Anthony Edward Hall"

#define NewtonEOF         EOF             // -1
#define NewtonOK          0
#define NewtonERROR       1
#define NewtonEOL         '\n'            // Newton's EOL character (^J)

#define SlurpeeBYE        "BYE!\n"        // Slurpee's Done
#define SlurpeeDUMP       "DUMP!\n"       // Slurpee's Dump
#define SlurpeeNoteDelim  "-----\n"       // Notes delimiter

  class Newton
    {
    private:
      SFile NewtonDevice;              // The Newton Device Itself!
      String NewtonDeviceName;         // The Newton Device (as in /dev/tty1)!

      //
      // Methods in Outbox.C
      //
      int ProcessOutbox(const int);    // Process the Outbox

      //
      // Methods in Inbox.C
      //
      int ProcessInbox(const int);     // Process the Inbox

    public:
      //
      // Methods in Newton.C
      //
      Newton();
      ~Newton();
      int Open(String);             // open Newton serial port
      int Open(const char *);
      int Close();                  // close Newton serial port
      int Flush();                  // flush Newton serial port 
      int isOpen();                 // TRUE if Newton is open, else FALSE
      int isConnected();            // TRUE if Newton is connected to Slurpee
      int wakeUp();                 // Wake up Newton if it's asleep

      //
      // Methods in Read.C
      //
      int ReadChar(char &);         // read a character fro Newton
      int ReadLine(String &);       // read from Newton until NewtonEOL
      int ReadLine(char **);
      int ReadToFile(const String); // read from Newton to a file
      int ReadToFile(const char *);
      int ReadToFile(const FILE *);

      //
      // Methods in Write.C
      //
      int WriteChar(const char);                 // write a character to Newton
      int WriteString(const String);             // write a String to Newton
      int WriteString(const char *);             // write a string to Newton
      int WriteFromFile(const String, const bool); // write file to Newton
      int WriteFromFile(const char *, const bool);
      int WriteFromFile(const FILE *, const bool);

      //
      // Methods in NPP.C
      //
      String NewtPreProcessor(const String); // preprocess a Newt file
      String NewtPreProcessor(const char *);
      String NewtPreProcessor(const FILE *);

      //
      // Methods in Outbox.C
      //
      int PrintOutbox();
      int FaxOutbox();
      int BeamOutbox();
      int EmailOutbox(); 

      //
      // Methods in Inbox.C
      //
      int BeamInbox();
      int EnhancementInbox();
      int EmailInbox(); 

    };

#endif

